@@ -1,5 +1,5 @@
 // main88.cc is a part of the PYTHIA event generator.
-// Copyright (C) 2020 Torbjorn Sjostrand.
+// Copyright (C) 2021 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL v2 or later, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -15,7 +15,11 @@
 // example requires HepMC 3.
 
 #include "Pythia8/Pythia.h"
+#ifndef HEPMC2
 #include "Pythia8Plugins/HepMC3.h"
+#else
+#include "Pythia8Plugins/HepMC2.h"
+#endif
 #include <unistd.h>
 
 using namespace Pythia8;
@@ -50,16 +54,14 @@ int main( int argc, char* argv[] ){
   pythia.readString("Weights:suppressAUX = on");
 
   // Interface for conversion from Pythia8::Event to HepMC one.
-  HepMC3::Pythia8ToHepMC3 toHepMC;
   // Specify file where HepMC events will be stored.
-  HepMC3::WriterAscii ascii_io(argv[3]);
+  Pythia8ToHepMC toHepMC(argv[3]);
   // Switch off warnings for parton-level events.
   toHepMC.set_print_inconsistency(false);
   toHepMC.set_free_parton_warnings(false);
-  // Do not store cross section information, as this will be done manually.
+  // Do not store all information.
   toHepMC.set_store_pdf(false);
   toHepMC.set_store_proc(false);
-  toHepMC.set_store_xsec(false);
 
   // Path to input events, with name up to the "_tree", "_powheg" identifier
   // included.
@@ -238,8 +240,6 @@ int main( int argc, char* argv[] ){
   njetcounterLO = nMaxLO;
   iPathTree     = iPath + "_tree";
 
-  bool wroteRunInfo = false;
-
   while(njetcounterLO >= 0){
 
     // From njetcounter, choose LHE file
@@ -280,39 +280,22 @@ int main( int argc, char* argv[] ){
       // Do not print zero-weight events.
       if ( weightNLO == 0. ) continue;
 
-      // Create a GenRunInfo object with the necessary weight names and write
-      // them to the HepMC3 file only once.
-      if (!wroteRunInfo) {
-        shared_ptr<HepMC3::GenRunInfo> genRunInfo;
-        genRunInfo = make_shared<HepMC3::GenRunInfo>();
-        vector<string> weight_names = pythia.info.weightNameVector();
-        genRunInfo->set_weight_names(weight_names);
-        ascii_io.set_run_info(genRunInfo);
-        ascii_io.write_run_info();
-        wroteRunInfo = true;
-      }
+      // Copy the weight names to HepMC.
+      toHepMC.setWeightNames(pythia.info.weightNameVector());
 
-      // Construct new empty HepMC event.
-      HepMC3::GenEvent hepmcevt;
       // Get correct cross section from previous estimate.
       double normhepmc = xsecLO[iNow] / nAcceptLO[iNow];
-      // Set hepmc event weight.
-      hepmcevt.weights().push_back(weightNLO*normhepmc);
       // Fill HepMC event.
-      toHepMC.fill_next_event( pythia, &hepmcevt );
+      toHepMC.fillNextEvent( pythia );
+
       // Add the weight of the current event to the cross section.
       sigmaTotal += weightNLO*normhepmc;
       sigmaTemp  += weightNLO*normhepmc;
       errorTotal += pow2(weightNLO*normhepmc);
       // Report cross section to hepmc.
-      shared_ptr<HepMC3::GenCrossSection> xsec;
-      xsec = make_shared<HepMC3::GenCrossSection>();
-      // First add object to event, then set cross section. This order ensures
-      // that the lengths of the cross section and the weight vector agree.
-      hepmcevt.set_cross_section( xsec );
-      xsec->set_cross_section( sigmaTotal*1e9, pythia.info.sigmaErr()*1e9 );
+      toHepMC.setXSec( sigmaTotal*1e9, pythia.info.sigmaErr()*1e9 );
       // Write the HepMC event to file.
-      ascii_io.write_event(hepmcevt);
+      toHepMC.writeEvent();
     } // end loop over events to generate
 
     // print cross section, errors
@@ -384,42 +367,25 @@ int main( int argc, char* argv[] ){
       // Do not print zero-weight events.
       if ( weightNLO == 0. ) continue;
 
-      // Create a GenRunInfo object with the necessary weight names and write
-      // them to the HepMC3 file only once.
-      if (!wroteRunInfo) {
-        shared_ptr<HepMC3::GenRunInfo> genRunInfo;
-        genRunInfo = make_shared<HepMC3::GenRunInfo>();
-        vector<string> weight_names = pythia.info.weightNameVector();
-        genRunInfo->set_weight_names(weight_names);
-        ascii_io.set_run_info(genRunInfo);
-        ascii_io.write_run_info();
-        wroteRunInfo = true;
-      }
+      // Copy the weight names to HepMC.
+      toHepMC.setWeightNames(pythia.info.weightNameVector());
 
-      // Construct new empty HepMC event.
-      HepMC3::GenEvent hepmcevt;
       // Get correct cross section from previous estimate.
       double normhepmc = xsecNLO[iNow] / nAcceptNLO[iNow];
       // powheg weighted events
       if( abs(strategyNLO[iNow]) == 4)
         normhepmc = 1. / (1e9*nSelectedNLO[iNow]);
-      // Set hepmc event weight.
-      hepmcevt.weights().push_back(weightNLO*normhepmc);
       // Fill HepMC event.
-      toHepMC.fill_next_event( pythia, &hepmcevt );
+      toHepMC.fillNextEvent( pythia );
+
       // Add the weight of the current event to the cross section.
       sigmaTotal += weightNLO*normhepmc;
       sigmaTemp  += weightNLO*normhepmc;
       errorTotal += pow2(weightNLO*normhepmc);
       // Report cross section to hepmc.
-      shared_ptr<HepMC3::GenCrossSection> xsec;
-      xsec = make_shared<HepMC3::GenCrossSection>();
-      // First add object to event, then set cross section. This order ensures
-      // that the lengths of the cross section and the weight vector agree.
-      hepmcevt.set_cross_section( xsec );
-      xsec->set_cross_section( sigmaTotal*1e9, pythia.info.sigmaErr()*1e9 );
+      toHepMC.setXSec( sigmaTotal*1e9, pythia.info.sigmaErr()*1e9 );
       // Write the HepMC event to file.
-      ascii_io.write_event(hepmcevt);
+      toHepMC.writeEvent();
 
     } // end loop over events to generate
 
@@ -492,39 +458,22 @@ int main( int argc, char* argv[] ){
       // Do not print zero-weight events.
       if ( weightNLO == 0. ) continue;
 
-      // Create a GenRunInfo object with the necessary weight names and write
-      // them to the HepMC3 file only once.
-      if (!wroteRunInfo) {
-        shared_ptr<HepMC3::GenRunInfo> genRunInfo;
-        genRunInfo = make_shared<HepMC3::GenRunInfo>();
-        vector<string> weight_names = pythia.info.weightNameVector();
-        genRunInfo->set_weight_names(weight_names);
-        ascii_io.set_run_info(genRunInfo);
-        ascii_io.write_run_info();
-        wroteRunInfo = true;
-      }
+      // Copy the weight names to HepMC.
+      toHepMC.setWeightNames(pythia.info.weightNameVector());
 
-      // Construct new empty HepMC event.
-      HepMC3::GenEvent hepmcevt;
       // Get correct cross section from previous estimate.
       double normhepmc = -1*xsecLO[iNow] / nAcceptLO[iNow];
-      // Set hepmc event weight.
-      hepmcevt.weights().push_back(weightNLO*normhepmc);
       // Fill HepMC event.
-      toHepMC.fill_next_event( pythia, &hepmcevt );
+      toHepMC.fillNextEvent( pythia );
+
       // Add the weight of the current event to the cross section.
       sigmaTotal += weightNLO*normhepmc;
       sigmaTemp  += weightNLO*normhepmc;
       errorTotal += pow2(weightNLO*normhepmc);
       // Report cross section to hepmc.
-      shared_ptr<HepMC3::GenCrossSection> xsec;
-      xsec = make_shared<HepMC3::GenCrossSection>();
-      // First add object to event, then set cross section. This order ensures
-      // that the lengths of the cross section and the weight vector agree.
-      hepmcevt.set_cross_section( xsec );
-      xsec->set_cross_section( sigmaTotal*1e9, pythia.info.sigmaErr()*1e9 );
+      toHepMC.setXSec( sigmaTotal*1e9, pythia.info.sigmaErr()*1e9 );
       // Write the HepMC event to file.
-      ascii_io.write_event(hepmcevt);
+      toHepMC.writeEvent();
 
     } // end loop over events to generate
 
@@ -596,42 +545,25 @@ int main( int argc, char* argv[] ){
       // Do not print zero-weight events.
       if ( weightNLO == 0. ) continue;
 
-      // Create a GenRunInfo object with the necessary weight names and write
-      // them to the HepMC3 file only once.
-      if (!wroteRunInfo) {
-        shared_ptr<HepMC3::GenRunInfo> genRunInfo;
-        genRunInfo = make_shared<HepMC3::GenRunInfo>();
-        vector<string> weight_names = pythia.info.weightNameVector();
-        genRunInfo->set_weight_names(weight_names);
-        ascii_io.set_run_info(genRunInfo);
-        ascii_io.write_run_info();
-        wroteRunInfo = true;
-      }
+      // Copy the weight names to HepMC.
+      toHepMC.setWeightNames(pythia.info.weightNameVector());
 
-      // Construct new empty HepMC event.
-      HepMC3::GenEvent hepmcevt;
       // Get correct cross section from previous estimate.
       double normhepmc = -1*xsecNLO[iNow] / nAcceptNLO[iNow];
       // powheg weighted events
       if( abs(strategyNLO[iNow]) == 4)
         normhepmc = -1. / (1e9*nSelectedNLO[iNow]);
-      // Set hepmc event weight.
-      hepmcevt.weights().push_back(weightNLO*normhepmc);
       // Fill HepMC event.
-      toHepMC.fill_next_event( pythia, &hepmcevt );
+      toHepMC.fillNextEvent( pythia );
+
       // Add the weight of the current event to the cross section.
       sigmaTotal += weightNLO*normhepmc;
       sigmaTemp  += weightNLO*normhepmc;
       errorTotal += pow2(weightNLO*normhepmc);
       // Report cross section to hepmc.
-      shared_ptr<HepMC3::GenCrossSection> xsec;
-      xsec = make_shared<HepMC3::GenCrossSection>();
-      // First add object to event, then set cross section. This order ensures
-      // that the lengths of the cross section and the weight vector agree.
-      hepmcevt.set_cross_section( xsec );
-      xsec->set_cross_section( sigmaTotal*1e9, pythia.info.sigmaErr()*1e9 );
+      toHepMC.setXSec( sigmaTotal*1e9, pythia.info.sigmaErr()*1e9 );
       // Write the HepMC event to file.
-      ascii_io.write_event(hepmcevt);
+      toHepMC.writeEvent();
 
     } // end loop over events to generate
 
